#[repr(transparent)]pub struct WriteProtection(pub [u8; 3]);Expand description
User write protection.
This is the packed representation of WriteProtectionUnpacked.
Tuple Fields
0: [u8; 3]Implementations
Sourceimpl WriteProtection
impl WriteProtection
Sourcepub fn write_key(&mut self, value: ProtectionKey)
pub fn write_key(&mut self, value: ProtectionKey)
Packs and updates the value of the key field in this packed representation.
Default: ProtectionKey :: Locked
Bits: [16..=23]
Sourcepub fn with_key(self, value: ProtectionKey) -> Self
pub fn with_key(self, value: ProtectionKey) -> Self
Packs and updates the value of the key field in this packed representation.
Chainable version of Self::write_key.
Default: ProtectionKey :: Locked
Bits: [16..=23]
Sourcepub fn read_key(&self) -> ProtectionKey
pub fn read_key(&self) -> ProtectionKey
Unpacks only the key field from this packed representation.
Default: ProtectionKey :: Locked
Bits: [16..=23]
Sourceimpl WriteProtection
impl WriteProtection
Sourcepub fn unpack(&self) -> WriteProtectionUnpacked
pub fn unpack(&self) -> WriteProtectionUnpacked
Unpack all fields into a WriteProtectionUnpacked. If you don’t need all fields, this is more expensive than just using the appropriate read_* functions directly.