SensorMode

Enum SensorMode 

pub enum SensorMode {
    Sleep,
    Forced,
    Normal,
    Invalid(u8),
}
Sensor operating mode

Enum width: 2 bits

Variants



Sleep

Sleep mode is entered by default after power on reset. In sleep mode, no measurements are performed and power consumption is at a minimum. All registers are accessible. There are no special restrictions on interface timings.

Value pattern: 0b00

Representative value: 0



Forced

In forced mode, a single measurement is performed in accordance to the selected measurement and filter options. When the measurement is finished, the sensor returns to sleep mode and the measurement results can be obtained from the data registers. For a next measurement, forced mode needs to be selected again. Using forced mode is recommended for applications which require low sampling rate or host-based synchronization.

Value pattern: 0b01

Representative value: 1



Normal

Normal mode comprises an automated perpetual cycling between an (active) measurement period and an (inactive) standby period. The measurements are performed in accordance to the selected measurement and filter options. The standby time is determined by the standby_time setting in the Config register and can be set to between 0.5 and 1000 ms.

Value pattern: 0b11

Representative value: 3



Invalid(u8)

Invalid sensor mode

Value pattern: _

Captures the specific value.