ControlMeasurement

Struct ControlMeasurement 

#[repr(transparent)]
pub struct ControlMeasurement(pub [u8; 1]);
The measurement control register sets the pressure and temperature data acquisition options of the device. The register needs to be written after changing ControlHumidity for those changes to become effective.

This is the packed representation of ControlMeasurementUnpacked.

Tuple Fields

0: [u8; 1]

Implementations

Source

impl ControlMeasurement

pub fn write_temperature_oversampling(&mut self, value: Oversampling)

Packs and updates the value of the temperature_oversampling field in this packed representation.

Controls oversampling of temperature data.

Default: Oversampling :: Disabled

Bits: [0..=2]

pub fn with_temperature_oversampling(self, value: Oversampling) -> Self

Packs and updates the value of the temperature_oversampling field in this packed representation.

Chainable version of Self::write_temperature_oversampling.

Controls oversampling of temperature data.

Default: Oversampling :: Disabled

Bits: [0..=2]

pub fn read_temperature_oversampling(&self) -> Oversampling

Unpacks only the temperature_oversampling field from this packed representation.

Controls oversampling of temperature data.

Default: Oversampling :: Disabled

Bits: [0..=2]

pub fn write_pressure_oversampling(&mut self, value: Oversampling)

Packs and updates the value of the pressure_oversampling field in this packed representation.

Controls oversampling of pressure data.

Default: Oversampling :: Disabled

Bits: [3..=5]

pub fn with_pressure_oversampling(self, value: Oversampling) -> Self

Packs and updates the value of the pressure_oversampling field in this packed representation.

Chainable version of Self::write_pressure_oversampling.

Controls oversampling of pressure data.

Default: Oversampling :: Disabled

Bits: [3..=5]

pub fn read_pressure_oversampling(&self) -> Oversampling

Unpacks only the pressure_oversampling field from this packed representation.

Controls oversampling of pressure data.

Default: Oversampling :: Disabled

Bits: [3..=5]

pub fn write_sensor_mode(&mut self, value: SensorMode)

Packs and updates the value of the sensor_mode field in this packed representation.

Controls operating mode of the sensor.

Default: SensorMode :: Sleep

Bits: [6..=7]

pub fn with_sensor_mode(self, value: SensorMode) -> Self

Packs and updates the value of the sensor_mode field in this packed representation.

Chainable version of Self::write_sensor_mode.

Controls operating mode of the sensor.

Default: SensorMode :: Sleep

Bits: [6..=7]

pub fn read_sensor_mode(&self) -> SensorMode

Unpacks only the sensor_mode field from this packed representation.

Controls operating mode of the sensor.

Default: SensorMode :: Sleep

Bits: [6..=7]

Source

impl ControlMeasurement

pub fn unpack(&self) -> ControlMeasurementUnpacked

Unpack all fields into a ControlMeasurementUnpacked. If you don’t need all fields, this is more expensive than just using the appropriate read_* functions directly.