#[repr(transparent)]pub struct ControlHumidity(pub [u8; 1]);Expand description
The humidity control register. Changes to this register only become effective after a write to the ControlMeasurement register!
This is the packed representation of ControlHumidityUnpacked.
Tuple Fields
0: [u8; 1]Implementations
Sourceimpl ControlHumidity
impl ControlHumidity
Sourcepub fn write_oversampling(&mut self, value: Oversampling)
pub fn write_oversampling(&mut self, value: Oversampling)
Packs and updates the value of the oversampling field in this packed representation.
Controls oversampling of humidity data. The default is 1x, i.e., no oversampling.
Default: Oversampling :: X_1
Bits: [5..=7]
Sourcepub fn with_oversampling(self, value: Oversampling) -> Self
pub fn with_oversampling(self, value: Oversampling) -> Self
Packs and updates the value of the oversampling field in this packed representation.
Chainable version of Self::write_oversampling.
Controls oversampling of humidity data. The default is 1x, i.e., no oversampling.
Default: Oversampling :: X_1
Bits: [5..=7]
Sourcepub fn read_oversampling(&self) -> Oversampling
pub fn read_oversampling(&self) -> Oversampling
Unpacks only the oversampling field from this packed representation.
Controls oversampling of humidity data. The default is 1x, i.e., no oversampling.
Default: Oversampling :: X_1
Bits: [5..=7]
Sourceimpl ControlHumidity
impl ControlHumidity
Sourcepub fn unpack(&self) -> ControlHumidityUnpacked
pub fn unpack(&self) -> ControlHumidityUnpacked
Unpack all fields into a ControlHumidityUnpacked. If you don’t need all fields, this is more expensive than just using the appropriate read_* functions directly.